@@ -15,8 +15,16 @@ class CreatePayoutAccount:
         conn = http.client.HTTPSConnection(self.endpoint)
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
-        # Send the request
-        conn.request('POST', self.route, json_data, headers)
-        response = json.loads(conn.getresponse().read().decode())
-
-        return response
+        try:
+            # Send the request
+            conn.request('POST', self.route, json_data, headers)
+            response = conn.getresponse()
+            if response.status == 200:
+                return json.loads(response.read().decode())
+            else:
+                return {
+                    "code": response.status,
+                    "error": response.reason
+                }
+        finally:
+            conn.close()
